Stan Math Library: stan/math/mix/mat.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mat.hpp File Reference
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/fwd/scal/meta/is_fvar.hpp>`
`#include <stan/math/fwd/scal/meta/partials_type.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/scal/meta/is_var.hpp>`
`#include <stan/math/rev/scal/meta/partials_type.hpp>`
`#include <stan/math/prim/mat.hpp>`
`#include <stan/math/fwd/mat.hpp>`
`#include <stan/math/rev/mat.hpp>`
`#include <stan/math/mix/mat/fun/typedefs.hpp>`
`#include <stan/math/mix/mat/functor/derivative.hpp>`
`#include <stan/math/mix/mat/functor/finite_diff_grad_hessian.hpp>`
`#include <stan/math/mix/mat/functor/grad_hessian.hpp>`
`#include <stan/math/mix/mat/functor/grad_tr_mat_times_hessian.hpp>`
`#include <stan/math/mix/mat/functor/gradient_dot_vector.hpp>`
`#include <stan/math/mix/mat/functor/hessian.hpp>`
`#include <stan/math/mix/mat/functor/hessian_times_vector.hpp>`
`#include <stan/math/mix/mat/functor/partial_derivative.hpp>`

Go to the source code of this file.

[ Stan Home Page ] © 2011–2016, Stan Development Team.